@@ -6,7 +6,9 @@ from typing import TYPE_CHECKING
 import pytest
 from git import Repo
 
-from tests.const import EXAMPLE_HVCS_DOMAIN
+from semantic_release.cli.config import ChangelogOutputFormat
+
+from tests.const import EXAMPLE_HVCS_DOMAIN, NULL_HEX_SHA
 from tests.util import copy_dir_tree, temporary_working_directory
 
 if TYPE_CHECKING:
@@ -44,11 +46,11 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "Initial commit",
-                    "emoji": "Initial commit",
-                    "scipy": "Initial commit",
-                    "tag": "Initial commit",
-                }
+                    "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "tag": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                },
             ],
         },
         "0.1.1-rc.1": {
@@ -60,10 +62,13 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "fix: add some more text",
-                    "emoji": ":bug: add some more text",
-                    "scipy": "MAINT: add some more text",
-                    "tag": ":nut_and_bolt: add some more text",
+                    "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
                 }
             ],
         },
@@ -76,10 +81,22 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "feat!: add some more text",
-                    "emoji": ":boom: add some more text",
-                    "scipy": "API: add some more text",
-                    "tag": ":sparkles: add some more text\n\nBREAKING CHANGE: add some more text",
+                    "angular": {
+                        "msg": "feat!: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":boom: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "API: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":sparkles: add revolutionary feature\n\nBREAKING CHANGE: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
                 }
             ],
         },
@@ -92,11 +109,17 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "feat: add some more text",
-                    "emoji": ":sparkles: add some more text",
-                    "scipy": "ENH: add some more text",
-                    "tag": ":sparkles: add some more text",
-                },
+                    "angular": {"msg": "feat: add some more text", "sha": NULL_HEX_SHA},
+                    "emoji": {
+                        "msg": ":sparkles: add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":sparkles: add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
         "1.1.0": {
@@ -108,11 +131,23 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "feat(dev): add some more text",
-                    "emoji": ":sparkles: (dev) add some more text",
-                    "scipy": "ENH: (dev) add some more text",
-                    "tag": ":sparkles: (dev) add some more text",
-                },
+                    "angular": {
+                        "msg": "feat(dev): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: (dev) add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(dev): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":sparkles: (dev) add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
         "1.1.1": {
@@ -124,11 +159,23 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "fix(dev): add some more text",
-                    "emoji": ":bug: (dev) add some more text",
-                    "scipy": "MAINT: (dev) add some more text",
-                    "tag": ":nut_and_bolt: (dev) add some more text",
-                },
+                    "angular": {
+                        "msg": "fix(dev): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":bug: correct dev-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "MAINT(dev): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct dev-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
         "1.2.0-alpha.1": {
@@ -140,11 +187,20 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "feat(feature): add some more text",
-                    "emoji": ":sparkles: (feature) add some more text",
-                    "scipy": "ENH: (feature) add some more text",
-                    "tag": ":sparkles: (feature) add some more text",
-                },
+                    "angular": {
+                        "msg": "feat(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: add scoped change",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {"msg": ":sparkles: add scoped change", "sha": NULL_HEX_SHA},
+                }
             ],
         },
         "1.2.0-alpha.2": {
@@ -171,16 +227,37 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
             },
             "commits": [
                 {
-                    "angular": "feat(feature): add some more text",
-                    "emoji": ":sparkles: (feature) add some more text",
-                    "scipy": "ENH: (feature) add some more text",
-                    "tag": ":sparkles: (feature) add some more text",
+                    "angular": {
+                        "msg": "feat(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: add scoped change",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {"msg": ":sparkles: add scoped change", "sha": NULL_HEX_SHA},
                 },
                 {
-                    "angular": "fix(feature): add some missing text",
-                    "emoji": ":bug: (feature) add some missing text",
-                    "scipy": "MAINT: (feature) add some missing text",
-                    "tag": ":nut_and_bolt: (feature) add some missing text",
+                    "angular": {
+                        "msg": "fix(scope): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":bug: correct feature-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "MAINT(scope): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct feature-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
                 },
             ],
         },
@@ -199,7 +276,7 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 ),
                 "commits": [
                     # Extract the correct commit message for the commit type
-                    message_variants[commit_type]
+                    deepcopy(message_variants[commit_type])
                     for message_variants in version_def["commits"]
                 ],
             }
@@ -225,6 +302,7 @@ def build_git_flow_repo_with_2_release_channels(
     build_configured_base_repo: BuildRepoFn,
     default_tag_format_str: str,
     changelog_md_file: Path,
+    changelog_rst_file: Path,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
     simulate_default_changelog_creation: SimulateDefaultChangelogCreationFn,
     create_release_tagged_commit: CreateReleaseFn,
@@ -276,14 +354,26 @@ def build_git_flow_repo_with_2_release_channels(
         with temporary_working_directory(repo_dir), Repo(".") as git_repo:
             # commit initial files & update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Publish initial feature release (v0.1.0) [updates tool.poetry.version]
@@ -296,14 +386,26 @@ def build_git_flow_repo_with_2_release_channels(
             # Prepare to do a prerelease (by adding a change)
             # modify && commit modification -> update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a patch level release candidate (v0.1.1-rc.1)
@@ -316,14 +418,26 @@ def build_git_flow_repo_with_2_release_channels(
             # Prepare for a major feature release
             # modify && commit modification -> update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a major feature release candidate (v1.0.0-rc.1)
@@ -336,14 +450,26 @@ def build_git_flow_repo_with_2_release_channels(
             # Prepare for a major feature release
             # modify && commit modification -> update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a major feature release (v1.0.0)
@@ -362,14 +488,26 @@ def build_git_flow_repo_with_2_release_channels(
             # Prepare for a minor feature release
             # modify && commit modification -> update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # TODO: ERROR releasing on dev branch
@@ -383,14 +521,26 @@ def build_git_flow_repo_with_2_release_channels(
             # Prepare for a patch level release
             # modify && commit modification -> update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # TODO: ERROR releasing on dev branch
@@ -408,14 +558,26 @@ def build_git_flow_repo_with_2_release_channels(
             # Prepare for an alpha prerelease
             # modify && commit modification -> update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make an alpha prerelease (v1.2.0-alpha.1) on the feature branch
@@ -427,13 +589,26 @@ def build_git_flow_repo_with_2_release_channels(
 
             # Prepare for a 2nd prerelease with 2 commits
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write expected changelog (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a 2nd alpha prerelease (v1.2.0-alpha.2) on the feature branch
