@@ -6,7 +6,9 @@ from typing import TYPE_CHECKING
 import pytest
 from git import Repo
 
-from tests.const import EXAMPLE_HVCS_DOMAIN
+from semantic_release.cli.config import ChangelogOutputFormat
+
+from tests.const import EXAMPLE_HVCS_DOMAIN, NULL_HEX_SHA
 from tests.util import copy_dir_tree, temporary_working_directory
 
 if TYPE_CHECKING:
@@ -44,11 +46,11 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "Initial commit",
-                    "emoji": "Initial commit",
-                    "scipy": "Initial commit",
-                    "tag": "Initial commit",
-                }
+                    "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "tag": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                },
             ],
         },
         "0.1.1-rc.1": {
@@ -60,10 +62,13 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "fix: add some more text",
-                    "emoji": ":bug: add some more text",
-                    "scipy": "MAINT: add some more text",
-                    "tag": ":nut_and_bolt: add some more text",
+                    "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
+                    "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
+                    "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
                 }
             ],
         },
@@ -76,10 +81,22 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "feat!: add some more text",
-                    "emoji": ":boom: add some more text",
-                    "scipy": "API: add some more text",
-                    "tag": ":sparkles: add some more text\n\nBREAKING CHANGE: add some more text",
+                    "angular": {
+                        "msg": "feat!: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":boom: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "API: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":sparkles: add revolutionary feature\n\nBREAKING CHANGE: add revolutionary feature",
+                        "sha": NULL_HEX_SHA,
+                    },
                 }
             ],
         },
@@ -92,11 +109,17 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "feat: add some more text",
-                    "emoji": ":sparkles: add some more text",
-                    "scipy": "ENH: add some more text",
-                    "tag": ":sparkles: add some more text",
-                },
+                    "angular": {"msg": "feat: add some more text", "sha": NULL_HEX_SHA},
+                    "emoji": {
+                        "msg": ":sparkles: add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
+                    "tag": {
+                        "msg": ":sparkles: add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
         "1.1.0-rc.1": {
@@ -108,11 +131,23 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "feat(dev): add some more text",
-                    "emoji": ":sparkles: (dev) add some more text",
-                    "scipy": "ENH: (dev) add some more text",
-                    "tag": ":sparkles: (dev) add some more text",
-                },
+                    "angular": {
+                        "msg": "feat(dev): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: (dev) add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(dev): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":sparkles: (dev) add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
         "1.1.0-rc.2": {
@@ -124,11 +159,23 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "fix(dev): add some more text",
-                    "emoji": ":bug: (dev) add some more text",
-                    "scipy": "MAINT: (dev) add some more text",
-                    "tag": ":nut_and_bolt: (dev) add some more text",
-                },
+                    "angular": {
+                        "msg": "fix(dev): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":bug: correct dev-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "MAINT(dev): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct dev-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
         "1.1.0-alpha.1": {
@@ -140,11 +187,20 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "feat(feature): add some more text",
-                    "emoji": ":sparkles: (feature) add some more text",
-                    "scipy": "ENH: (feature) add some more text",
-                    "tag": ":sparkles: (feature) add some more text",
-                },
+                    "angular": {
+                        "msg": "feat(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: add scoped change",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {"msg": ":sparkles: add scoped change", "sha": NULL_HEX_SHA},
+                }
             ],
         },
         "1.1.0-alpha.2": {
@@ -156,10 +212,19 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "feat(feature): add some more text",
-                    "emoji": ":sparkles: (feature) add some more text",
-                    "scipy": "ENH: (feature) add some more text",
-                    "tag": ":sparkles: (feature) add some more text",
+                    "angular": {
+                        "msg": "feat(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":sparkles: add scoped change",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "ENH(scope): add some more text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {"msg": ":sparkles: add scoped change", "sha": NULL_HEX_SHA},
                 },
             ],
         },
@@ -172,11 +237,23 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": "fix(feature): add some missing text",
-                    "emoji": ":bug: (feature) add some missing text",
-                    "scipy": "MAINT: (feature) add some missing text",
-                    "tag": ":nut_and_bolt: (feature) add some missing text",
-                },
+                    "angular": {
+                        "msg": "fix(scope): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "emoji": {
+                        "msg": ":bug: correct feature-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "scipy": {
+                        "msg": "MAINT(scope): correct some text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                    "tag": {
+                        "msg": ":nut_and_bolt: correct feature-scoped text",
+                        "sha": NULL_HEX_SHA,
+                    },
+                }
             ],
         },
     }
@@ -194,7 +271,7 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 ),
                 "commits": [
                     # Extract the correct commit message for the commit type
-                    message_variants[commit_type]
+                    deepcopy(message_variants[commit_type])
                     for message_variants in version_def["commits"]
                 ],
             }
@@ -220,6 +297,7 @@ def build_git_flow_repo_w_3_release_channels(
     build_configured_base_repo: BuildRepoFn,
     default_tag_format_str: str,
     changelog_md_file: Path,
+    changelog_rst_file: Path,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
     simulate_default_changelog_creation: SimulateDefaultChangelogCreationFn,
     create_release_tagged_commit: CreateReleaseFn,
@@ -269,14 +347,26 @@ def build_git_flow_repo_w_3_release_channels(
         with temporary_working_directory(repo_dir), Repo(".") as git_repo:
             # commit initial files & update commit msg with sha & url
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make initial feature release (v0.1.0)
@@ -288,14 +378,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Prepare for a prerelease
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a patch level release candidate (v0.1.1-rc.1)
@@ -307,14 +409,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Prepare for a major feature release
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a major feature release candidate (v1.0.0-rc.1)
@@ -326,14 +440,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Add non-breaking feature commit
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a major feature release (v1.0.0)
@@ -349,14 +475,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Prepare for a minor bump release candidate
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a minor bump release candidate (v1.1.0-rc.1)
@@ -368,14 +506,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Make a patch level commit
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a 2nd release candidate (v1.1.0-rc.2)
@@ -391,14 +541,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Make a feature commit
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make an alpha prerelease (v1.1.0-alpha.1)
@@ -410,14 +572,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Make a another feature commit
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write changelog to this version (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
                 max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a 2nd alpha prerelease (v1.1.0-alpha.2)
@@ -429,13 +603,26 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Make a patch level commit
             next_version_def["commits"] = simulate_change_commits_n_rtn_changelog_entry(
-                git_repo, next_version_def["commits"], hvcs
+                git_repo,
+                next_version_def["commits"],
             )
 
-            # write expected changelog (should match template changelog)
+            # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
                 repo_def,
-                repo_dir.joinpath(changelog_md_file),
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_md_file),
+                output_format=ChangelogOutputFormat.MARKDOWN,
+            )
+
+            # write expected RST changelog to this version
+            simulate_default_changelog_creation(
+                repo_def,
+                hvcs=hvcs,
+                max_version=next_version,
+                dest_file=repo_dir.joinpath(changelog_rst_file),
+                output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
             )
 
             # Make a 3rd alpha prerelease (v1.1.0-alpha.3)
